[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [23970] branches/soc-2009-chingachgook/ source/blender/collada: Post-merge fixes in collada code.

Arystanbek Dyussenov arystan.d at gmail.com
Mon Oct 19 18:23:47 CEST 2009


Revision: 23970
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=23970
Author:   kazanbas
Date:     2009-10-19 18:23:45 +0200 (Mon, 19 Oct 2009)

Log Message:
-----------
Post-merge fixes in collada code.

Modified Paths:
--------------
    branches/soc-2009-chingachgook/source/blender/collada/DocumentExporter.cpp
    branches/soc-2009-chingachgook/source/blender/collada/DocumentImporter.cpp

Modified: branches/soc-2009-chingachgook/source/blender/collada/DocumentExporter.cpp
===================================================================
--- branches/soc-2009-chingachgook/source/blender/collada/DocumentExporter.cpp	2009-10-19 16:20:12 UTC (rev 23969)
+++ branches/soc-2009-chingachgook/source/blender/collada/DocumentExporter.cpp	2009-10-19 16:23:45 UTC (rev 23970)
@@ -1941,7 +1941,7 @@
 		bez.ipo = U.ipo_new; /* use default interpolation mode here... */
 		bez.f1 = bez.f2 = bez.f3 = SELECT;
 		bez.h1 = bez.h2 = HD_AUTO;
-		insert_bezt_fcurve(fcu, &bez);
+		insert_bezt_fcurve(fcu, &bez, 0);
 		calchandles_fcurve(fcu);
 	}
 	
@@ -2031,7 +2031,7 @@
 					continue;
 				
 				// if rotation mode is euler - no need to convert it
-				if (pchan->rotmode == PCHAN_ROT_EUL) {
+				if (pchan->rotmode == PCHAN_ROT_XYZ) {
 					
 					std::vector<FCurve*> &rotfcurves = rotfcurves_actionGroup_map[grp];
 					

Modified: branches/soc-2009-chingachgook/source/blender/collada/DocumentImporter.cpp
===================================================================
--- branches/soc-2009-chingachgook/source/blender/collada/DocumentImporter.cpp	2009-10-19 16:20:12 UTC (rev 23969)
+++ branches/soc-2009-chingachgook/source/blender/collada/DocumentImporter.cpp	2009-10-19 16:23:45 UTC (rev 23970)
@@ -37,7 +37,7 @@
 {
 #include "ED_keyframing.h"
 #include "ED_armature.h"
-#include "ED_mesh.h" // add_vert_to_defgroup, ...
+#include "ED_mesh.h" // ED_vgroup_vert_add, ...
 #include "ED_anim_api.h"
 #include "WM_types.h"
 #include "WM_api.h"
@@ -89,10 +89,13 @@
 #include <math.h>
 #include <float.h>
 
-#define COLLADA_DEBUG
+// #define COLLADA_DEBUG
 
 char *CustomData_get_layer_name(const struct CustomData *data, int type, int n);
 
+// armature module internal func, it's not good to use it here? (Arystan)
+struct EditBone *addEditBone(struct bArmature *arm, char *name);
+
 const char *primTypeToStr(COLLADAFW::MeshPrimitive::PrimitiveType type)
 {
 	using namespace COLLADAFW;
@@ -706,7 +709,7 @@
 
 	void set_euler_rotmode()
 	{
 		// just set rotmode = PCHAN_ROT_EUL on pose channel for each joint
 
 		std::map<COLLADAFW::UniqueId, COLLADAFW::Node*>::iterator it;
 
@@ -723,7 +726,7 @@
 					bPoseChannel *pchan = skin.get_pose_channel_from_node(joint);
 
 					if (pchan) {
-						pchan->rotmode = PCHAN_ROT_EUL;
+						pchan->rotmode = PCHAN_ROT_XYZ;
 					}
 					else {
 						fprintf(stderr, "Cannot find pose channel for %s.\n", get_joint_name(joint));
@@ -1756,7 +1759,7 @@
 		bez.ipo = U.ipo_new; /* use default interpolation mode here... */
 		bez.f1 = bez.f2 = bez.f3 = SELECT;
 		bez.h1 = bez.h2 = HD_AUTO;
-		insert_bezt_fcurve(fcu, &bez);
+		insert_bezt_fcurve(fcu, &bez, 0);
 		calchandles_fcurve(fcu);
 	}
 
@@ -1796,7 +1799,7 @@
 				bez.ipo = U.ipo_new; /* use default interpolation mode here... */
 				bez.f1 = bez.f2 = bez.f3 = SELECT;
 				bez.h1 = bez.h2 = HD_AUTO;
-				insert_bezt_fcurve(fcu, &bez);
+				insert_bezt_fcurve(fcu, &bez, 0);
 				calchandles_fcurve(fcu);
 			}
 
@@ -1829,7 +1832,7 @@
 					bez.ipo = U.ipo_new; /* use default interpolation mode here... */
 					bez.f1 = bez.f2 = bez.f3 = SELECT;
 					bez.h1 = bez.h2 = HD_AUTO;
-					insert_bezt_fcurve(fcu, &bez);
+					insert_bezt_fcurve(fcu, &bez, 0);
 					calchandles_fcurve(fcu);
 				}
 
@@ -706,7 +709,7 @@
 	void set_euler_rotmode()
 	{
-		// just set rotmode = PCHAN_ROT_EUL on pose channel for each joint
+		// just set rotmode = PCHAN_ROT_XYZ on pose channel for each joint
 
 		std::map<COLLADAFW::UniqueId, COLLADAFW::Node*>::iterator it;





More information about the Bf-blender-cvs mailing list